# cs207-FinalProject

Group name: rajayuco

Group number: 6

Team members: Rachel Moon, Jamila Pegues, Yudi Wang, Cory Williams

[![Build Status](https://travis-ci.org/rajayuco/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/rajayuco/cs207-FinalProject)

[![Coverage Status](https://coveralls.io/repos/github/rajayuco/cs207-FinalProject/badge.svg?branch=master)](https://coveralls.io/github/rajayuco/cs207-FinalProject?branch=master)
